require 'rails_helper'
include Warden::Test::Helpers

RSpec.describe 'hyrax/datasets/_attribute_rows', skip: true do
  # Create calls s3. Need to mock that
  admin_role = Role.find_by(name: "admin")
  user = admin_role.users.first
  let(:partial) { 'hyrax/datasets/attribute_rows' }
  let(:dataset) { create(:dataset, :open,  :with_doi, :with_complex_person, :with_complex_date,
                         :with_complex_identifier, :with_complex_funding_reference, :with_complex_relation) }
  let(:presenter) { Hyrax::DatasetPresenter.new(SolrDocument.new(dataset.to_solr), Ability.new(user), controller.request) }

  before do
    allow(controller).to receive(:current_user).and_return(user)
    login_as user if user.present?
    render partial: partial, locals: { presenter: presenter }
  end

  # NB: the visibility of individual metadata components is set in app/models/ability.rb
  # This test confirms the current expected behaviour (which is that most metadata is visible)

  context 'authenticated user' do
    it 'shows the correct metadata' do
      # doi
      expect(rendered).to have_content('1234-1567')
      # complex person
      expect(rendered).to have_content('Anamika')
      expect(rendered).to have_content('operator')
      expect(rendered).to have_content('University')
      # complex identifier
      expect(rendered).to have_content('doi:10.0.1111')
      # complex relation
      expect(rendered).to have_content('A relation label')
      expect(rendered).to have_content('is new version of')
      # complex funder reference
      expect(rendered).to have_content('f1234')
      expect(rendered).to have_content('Bank')
      expect(rendered).to have_content('a1234')
      expect(rendered).to have_content('http://example.com/a1234')
      expect(rendered).to have_content('No free lunch')
      # Abstract/Description is not displayed in this table partial
      expect(rendered).not_to have_content('Abstract-Description-123')
    end
  end
end
